@@ -96,7 +96,17 @@ class SoS_Exporter(Exporter):
         self.output_mimetype = 'text/x-sos'
         Exporter.__init__(self, config, **kwargs)
 
-    def from_notebook_cell(self, cell, fh, idx=0):
+    def content_from_notebook_cell(self, cell, fh, idx=0):
+        # in non-all mode, markdown cells are ignored because they can be mistakenly
+        # treated as markdown content of an action or script #806
+        if cell.cell_type != "code":
+            return
+        #
+        # Non-sos code cells are also ignored
+        fh.write(f'# cell {idx + 1}, kernel={cell.metadata["kernel"]}\n{cell.source}\n\n')
+        return idx
+
+    def workflow_from_notebook_cell(self, cell, fh, idx=0):
         # in non-all mode, markdown cells are ignored because they can be mistakenly
         # treated as markdown content of an action or script #806
         if cell.cell_type != "code":
@@ -133,9 +143,11 @@ class SoS_Exporter(Exporter):
         with StringIO() as fh:
             fh.write('#!/usr/bin/env sos-runner\n')
             fh.write('#fileformat=SOS1.0\n\n')
-            idx = 0
-            for cell in cells:
-                idx = self.from_notebook_cell(cell, fh, idx)
+            for idx, cell in enumerate(cells):
+                if 'all_content' in kwargs and kwargs['all_content']:
+                    self.content_from_notebook_cell(cell, fh, idx)
+                else:
+                    self.workflow_from_notebook_cell(cell, fh, idx)
             content = fh.getvalue()
         resources['output_extension'] = '.sos'
         return content, resources
@@ -300,6 +312,11 @@ class NotebookToScriptConverter(object):
             .sos file. The cells are presented in the .sos file as
             cell structure lines, which will be ignored if executed
             in batch mode ''')
+        parser.add_argument('-a',
+            '--all',
+            action='store_true',
+            help='''If set, export all cells to the output file, which
+                does not have to be a valid sos workflow.''')
         return parser
 
     def convert(self, notebook_file, sos_file, args=None, unknown_args=None):
@@ -310,7 +327,7 @@ class NotebookToScriptConverter(object):
             raise ValueError(f'Unrecognized parameter {unknown_args}')
         exporter = SoS_Exporter()
         notebook = nbformat.read(notebook_file, nbformat.NO_CONVERT)
-        output, _ = exporter.from_notebook_node(notebook, {})
+        output, _ = exporter.from_notebook_node(notebook, {}, all_content=args.all if args else False)
         if not sos_file:
             sys.stdout.write(output)
         elif isinstance(sos_file, str):
@@ -325,18 +342,9 @@ class NotebookToScriptConverter(object):
 # notebook to HTML
 #
 
-def get_template_args(name):
-    if not name:
-        return []
-    for path in [
-        '',
-        os.path.join('{os.path.split(os.path.abspath(sos.__file__))[0]}', 'templates'),
-        os.path.join('{os.path.split(os.path.abspath(__file__))[0]}', 'templates')]:
-        for template in [name, name + '.tpl']:
-            template_file = os.path.join(path, template)
-            if os.path.isfile(template_file):
-                return ['--template-file', template_file]
-    return []
+def get_template_args():
+    return ['--TemplateExporter.extra_template_basedirs', os.path.join(f'{os.path.split(os.path.abspath(__file__))[0]}', 'templates')]
+
 
 def export_notebook(exporter_class,
                     to_format,
@@ -390,6 +398,11 @@ def export_notebook(exporter_class,
         except Exception:
             pass
     else:
+        print([
+            'jupyter', 'nbconvert',
+            os.path.abspath(notebook_file), '--to', to_format, '--output',
+            os.path.abspath(output_file)
+        ] + ([] if unknown_args is None else unknown_args))
         ret = subprocess.call([
             'jupyter', 'nbconvert',
             os.path.abspath(notebook_file), '--to', to_format, '--output',
@@ -466,6 +479,12 @@ class NotebookToHTMLConverter(object):
                 where the type of value will be automatically guessed. An exception of this
                 rule is that `name' without `=` will be considered as value True.'''
         )
+        parser.add_argument(
+            '-a',
+            '--all',
+            action='store_true',
+            help='''If specified, save content of all cells to .sos file.'''
+        )
         parser.add_argument(
             '-v',
             '--view',
@@ -484,7 +503,7 @@ class NotebookToHTMLConverter(object):
         if unknown_args is None:
             unknown_args = []
         if sargs.template:
-            unknown_args = get_template_args(sargs.template) + unknown_args
+            unknown_args = get_template_args() + unknown_args
 
         if sargs.execute is not None:
             notebook_file = execute_sos_notebook(
@@ -552,13 +571,11 @@ class NotebookToPDFConverter(object):
 
         if unknown_args is None:
             unknown_args = []
-        if sargs.template:
-            unknown_args = get_template_args(sargs.template) + unknown_args
         # jupyter convert will add extension to output file...
         if output_file is not None and output_file.endswith('.pdf'):
             output_file = output_file[:-4]
         export_notebook(PDFExporter, 'pdf', notebook_file, output_file,
-                        unknown_args)
+                        get_template_args() + unknown_args)
 
         if os.path.basename(notebook_file).startswith('__tmp_output_nb'):
             try:
@@ -605,8 +622,7 @@ class NotebookToMarkdownConverter(object):
 
         export_notebook(
             MarkdownExporter, 'markdown', notebook_file, output_file,
-            unknown_args if '--template-file' in unknown_args else
-            ['--template', 'sos-markdown'] + unknown_args)
+            get_template_args() + ['--template', 'sos-markdown'] + unknown_args)
 
         if os.path.basename(notebook_file).startswith('__tmp_output_nb'):
             try:
